@@ -5,9 +5,9 @@ from mxcubecore.HardwareObjects.abstract import AbstractEnergy
 
 from mxcubeweb.core.adapter.actuator_adapter import ActuatorAdapter
 from mxcubeweb.core.adapter.wavelength_adapter import WavelengthAdapter
-from mxcubeweb.core.models.configmodels import AdapterResourceHandlerConfigModel
+from mxcubeweb.core.models.configmodels import ResourceHandlerConfigModel
 
-resource_handler_config = AdapterResourceHandlerConfigModel(
+resource_handler_config = ResourceHandlerConfigModel(
     commands=["get_value", "set_value", "stop", "get_resolution_limits_for_energy"],
     attributes=["data"],
 )
