@@ -1,4 +1,7 @@
+from typing import ClassVar
+
 from mxcubecore.BaseHardwareObjects import HardwareObjectState
+from mxcubecore.HardwareObjects.abstract import AbstractMachineInfo
 
 from mxcubeweb.core.adapter.adapter_base import ActuatorAdapterBase
 from mxcubeweb.core.models.adaptermodels import HOMachineInfoModel
@@ -8,6 +11,8 @@ from mxcubeweb.core.util.networkutils import RateLimited
 class MachineInfoAdapter(ActuatorAdapterBase):
     """Adapter for MachineInfo like objects"""
 
+    SUPPORTED_TYPES: ClassVar[list[object]] = [AbstractMachineInfo.AbstractMachineInfo]
+
     def __init__(self, ho, *args):
         """
         Args:
@@ -22,9 +27,9 @@ class MachineInfoAdapter(ActuatorAdapterBase):
 
     @RateLimited(0.1)
     def _value_change(self, *args, **kwargs):
-        self.value_change(self.get_value(), **kwargs)
+        self.value_change(self.get_value().value, **kwargs)
 
-    def _get_value(self) -> HOMachineInfoModel:
+    def get_value(self) -> HOMachineInfoModel:
         return HOMachineInfoModel(value=self.get_attributes())
 
     def get_attributes(self):
