@@ -6,10 +6,10 @@ from mxcubeweb.core.adapter.adapter_base import ActuatorAdapterBase
 from mxcubeweb.core.models.adaptermodels import (
     FloatValueModel,
 )
-from mxcubeweb.core.models.configmodels import AdapterResourceHandlerConfigModel
+from mxcubeweb.core.models.configmodels import ResourceHandlerConfigModel
 from mxcubeweb.core.util.networkutils import RateLimited
 
-resource_handler_config = AdapterResourceHandlerConfigModel(
+resource_handler_config = ResourceHandlerConfigModel(
     url_prefix="/mxcube/api/v0.1/motor_test",
     commands=["set_value", "get_value", "stop"],
     attributes=["data"],
