@@ -797,28 +797,6 @@ class Queue(ComponentBase):
 
         logging.getLogger("MX3.HWR").info("[QUEUE] is:\n%s " % self.queue_to_json())
 
-    def move_task_entry(self, sid, ti1, ti2):
-        """
-        Swaps order of two queue entries in the queue, with the same sample <sid>
-        as parent
-
-        :param str sid: Sample id
-        :param int ti1: Position of task1 (old position)
-        :param int ti2: Position of task2 (new position)
-        """
-        current_queue = self.queue_to_dict()
-
-        node_id = current_queue[sid]["queueID"]
-        smodel, sentry = self.get_entry(node_id)
-
-        # Swap the order in the queue model
-        smodel._children.insert(ti2, smodel._children.pop(ti1))
-
-        # Swap queue entry order
-        sentry._queue_entry_list.insert(ti2, sentry._queue_entry_list.pop(ti1))
-
-        logging.getLogger("MX3.HWR").info("[QUEUE] is:\n%s " % self.queue_to_json())
-
     def queue_add_item(self, item_list):
         """
         Adds the queue items in item_list to the queue. The items in the list can
@@ -1403,7 +1381,7 @@ class Queue(ComponentBase):
 
         return dc_model, dc_entry
 
-    def _create_xrf(self):
+    def _create_xrf(self, sample_model):
         """
         Creates a XRFSpectrum model.
 
@@ -1411,7 +1389,7 @@ class Queue(ComponentBase):
         :returns: The tuple (model, entry)
         :rtype: Tuple
         """
-        xrf_model = qmo.XRFSpectrum()
+        xrf_model = qmo.XRFSpectrum(sample=sample_model)
         xrf_model.set_origin(ORIGIN_MX3)
         xrf_entry = qe.XrfSpectrumQueueEntry(Mock(), xrf_model)
 
@@ -1670,7 +1648,7 @@ class Queue(ComponentBase):
         :rtype: int
         """
         sample_model, sample_entry = self.get_entry(node_id)
-        xrf_model, xrf_entry = self._create_xrf()
+        xrf_model, xrf_entry = self._create_xrf(sample_model)
         self.set_xrf_params(xrf_model, xrf_entry, task, sample_model)
 
         group_model = qmo.TaskGroup()
@@ -2164,76 +2142,6 @@ class Queue(ComponentBase):
             logging.getLogger("MX3.HWR").error(msg)
             raise ValueError(msg)
 
-    def toggle_node(self, node_id):
-        node = HWR.beamline.queue_model.get_node(node_id)
-        entry = HWR.beamline.queue_manager.get_entry_with_model(node)
-        queue = self.queue_to_dict()
-
-        if isinstance(entry, qe.SampleQueueEntry):
-            # this is a sample entry, thus, go through its checked children and
-            # toggle those
-            if entry.is_enabled():
-                entry.set_enabled(False)
-                node.set_enabled(False)
-            else:
-                entry.set_enabled(True)
-                node.set_enabled(True)
-
-            new_state = entry.is_enabled()
-            for elem in queue[node_id]:
-                child_node = HWR.beamline.queue_model.get_node(elem["queueID"])
-                child_entry = HWR.beamline.queue_manager.get_entry_with_model(
-                    child_node
-                )
-                if new_state:
-                    child_entry.set_enabled(True)
-                    child_node.set_enabled(True)
-                else:
-                    child_entry.set_enabled(False)
-                    child_node.set_enabled(False)
-
-        else:
-            # not a sample so find the parent and toggle directly
-            logging.getLogger("MX3.HWR").info(
-                "[QUEUE] toggling entry with id: %s" % node_id
-            )
-            # this is a TaskGroup, so it is not in the parsed queue
-            parent_node = node.get_parent()
-            # go a level up,
-            # this is a TaskGroup for a Char, a sampleQueueEntry if DataCol
-            parent_node = parent_node.get_parent()
-            if isinstance(parent_node, qmo.TaskGroup):
-                parent_node = parent_node.get_parent()
-            parent = parent_node._node_id
-            parent_entry = HWR.beamline.queue_manager.get_entry_with_model(parent_node)
-            # now that we know the sample parent no matter what is the entry
-            # (char, dc) check if the brother&sisters are enabled (and enable the
-            # parent)
-            checked = 0
-
-            for i in queue[parent]:
-                # at least one brother is enabled, no need to change parent
-                if i["queueID"] != node_id and i["checked"] == 1:
-                    checked = 1
-                    break
-            if entry.is_enabled():
-                entry.set_enabled(False)
-                node.set_enabled(False)
-
-            else:
-                entry.set_enabled(True)
-                node.set_enabled(True)
-
-            new_state = entry.is_enabled()
-            for met in queue[parent]:
-                if int(met.get("queueID")) == node_id:
-                    if new_state == 0 and checked == 0:
-                        parent_entry.set_enabled(False)
-                        parent_node.set_enabled(False)
-                    elif new_state == 1 and checked == 0:
-                        parent_entry.set_enabled(True)
-                        parent_node.set_enabled(True)
-
     def add_centring(self, _id, params):
         msg = "[QUEUE] centring add requested with data: " + str(params)
         logging.getLogger("MX3.HWR").info(msg)
