@@ -51,9 +51,7 @@ class HttpStreamer:
             )
 
     def _new_frame_received(self, img, width, height, *args, **kwargs):
-        if isinstance(img, str | bytes):
-            img = img
-        else:
+        if not isinstance(img, str | bytes):
             rawdata = img.bits().asstring(img.numBytes())
             strbuf = StringIO()
             image = PIL.Image.frombytes("RGBA", (width, height), rawdata)
@@ -223,7 +221,7 @@ class SampleView(ComponentBase):
         dm.connect("centringFailed", self.wait_for_centring_finishes)
         dm.connect("centringAccepted", self.centring_add_current_point)
         HWR.beamline.sample_view.connect("newGridResult", self.handle_grid_result)
-        self._click_limit = int(HWR.beamline.click_centring_num_clicks or 3)
+        self._click_limit = int(HWR.beamline.config.click_centring_num_clicks or 3)
 
     def set_image_size(self, width, height):
         HWR.beamline.sample_view.camera.restart_streaming((width, height))
@@ -396,9 +394,9 @@ class SampleView(ComponentBase):
             self.centring_reset_click_count()
         else:
             logging.getLogger("user_level_log").warning(
-                "Diffracomter is busy, cannot start centering"
+                "Diffractometer is busy, cannot start centering"
             )
-            msg = "Diffracomter is busy, cannot start centering"
+            msg = "Diffractometer is busy, cannot start centering"
             raise RuntimeError(msg)
 
         return {"clicksLeft": self.centring_clicks_left()}
@@ -413,8 +411,11 @@ class SampleView(ComponentBase):
 
     def centring_handle_click(self, x, y):
         if HWR.beamline.diffractometer.current_centring_procedure:
-            HWR.beamline.diffractometer.imageClicked(x, y, x, y)
-            self.centring_click()
+            try:
+                HWR.beamline.diffractometer.image_clicked(x, y, x, y)
+                self.centring_click()
+            except Exception:
+                return {"clicksLeft": -1}
         else:
             if not self.centring_clicks_left():
                 self.centring_reset_click_count()
