@@ -18,6 +18,8 @@ from mxcubeweb.core.components.component_base import ComponentBase
 from mxcubeweb.core.models.usermodels import User
 from mxcubeweb.core.util.networkutils import is_local_host
 
+HTTP_REQUESTS_TIMEOUT = 10  # Generic timeout for HTTP requests in seconds
+
 
 class BaseUserManager(ComponentBase):
     """Base class for managing user-related operations
@@ -237,6 +239,7 @@ class BaseUserManager(ComponentBase):
                     "grant_type": "refresh_token",
                     "refresh_token": current_user.refresh_token,
                 },
+                timeout=HTTP_REQUESTS_TIMEOUT,
             ).json()
         )
 
@@ -540,9 +543,10 @@ class UserManager(BaseUserManager):
             LimsSessionManager object with login information.
         """
         self._debug("_login. login_id=%s" % login_id)
+        local_domains = self.app.CONFIG.app.LOCAL_DOMAINS
         try:
             session_manager: LimsSessionManager = HWR.beamline.lims.login(
-                login_id, password, is_local_host()
+                login_id, password, is_local_host(local_domains)
             )
         except Exception as e:
             logging.getLogger("MX3.HWR").error(e)
@@ -559,23 +563,23 @@ class UserManager(BaseUserManager):
             else:
                 if current_user.username == login_id:
                     msg = "You are already logged in"
-                    raise Exception(msg)
+                    raise RuntimeError(msg)
                 msg = (
                     "Login rejected, you are already logged in"
                     " somewhere else\nand Another user is already"
                     " logged in"
                 )
-                raise Exception(msg)
+                raise RuntimeError(msg)
 
         # Only allow in-house log-in from local host
-        if self.is_inhouse_user(login_id) and not is_local_host():
+        if self.is_inhouse_user(login_id) and not is_local_host(local_domains):
             msg = "In-house only allowed from localhost"
-            raise Exception(msg)
+            raise PermissionError(msg)
 
         # Only allow local login when remote is disabled
-        if not self.app.ALLOW_REMOTE and not is_local_host():
+        if not self.app.ALLOW_REMOTE and not is_local_host(local_domains):
             msg = "Remote access disabled"
-            raise Exception(msg)
+            raise ConnectionRefusedError(msg)
 
         return session_manager
 
@@ -596,6 +600,7 @@ class UserManager(BaseUserManager):
                     "client_secret": self.app.CONFIG.sso.CLIENT_SECRET,
                     "refresh_token": refresh_token,
                 },
+                timeout=HTTP_REQUESTS_TIMEOUT,
             )
 
 
