@@ -10,7 +10,6 @@ from flask import (
     url_for,
 )
 from flask_login import current_user
-from mxcubecore import HardwareRepository as HWR
 
 from mxcubeweb.core.util import networkutils
 
@@ -64,10 +63,7 @@ def init_route(app, server, url_prefix):
     @bp.route("/ssologin", methods=["GET"])
     def ssosignin():
         redirect_uri = url_for("login.auth", _external=True)
-        response = app.usermanager.oauth_client.keycloak.authorize_redirect(
-            redirect_uri
-        )
-        return response
+        return app.usermanager.oauth_client.keycloak.authorize_redirect(redirect_uri)
 
     @bp.route("/auth", methods=["GET"])
     def auth():
