@@ -2,7 +2,6 @@ import contextlib
 import json
 import logging
 
-from flask import Response
 from mxcubecore import HardwareRepository as HWR
 from mxcubecore import queue_entry as qe
 from mxcubecore.HardwareObjects.abstract.AbstractSampleChanger import SampleChangerState
@@ -13,7 +12,6 @@ from mxcubeweb.app import MXCUBEApplication as mxcube
 from mxcubeweb.core.components.queue import (
     COLLECTED,
     FAILED,
-    READY,
     RUNNING,
     WARNING,
 )
@@ -36,13 +34,6 @@ def last_queue_node():
     return res
 
 
-beam_signals = [
-    "beamPosChanged",
-    "beamInfoChanged",
-    "valueChanged",
-    "stateChanged",
-]
-
 centringSignals = [
     "centringInvalid",
     "newAutomaticCentringPoint",
@@ -92,14 +83,6 @@ def handle_auto_mount_next(entry):
             logging.getLogger("user_level_log").info(msg)
 
 
-def diffractometer_phase_changed(*args):
-    data = {"msg": "Diffractometer phase changed", "phase": args}
-    logging.getLogger("user_level_log").info(
-        "Diffractometer phase changed to %s" % args
-    )
-    server.emit("diff_phase_changed", data, namespace="/hwr")
-
-
 def harvester_state_changed(*args):
     new_state = args[0]
     state_str = HarvesterState.STATE_DESC.get(new_state, "Unknown").upper()
@@ -592,73 +575,6 @@ def motor_position_callback(movable):
     server.emit("motor_position", movable, namespace="/hwr")
 
 
-def beam_changed(*args, **kwargs):
-    beam_info = HWR.beamline.beam
-
-    if beam_info is None:
-        logging.getLogger("HWR").error("beamInfo is not defined")
-        # TODO fix error
-        return Response(status=409)
-
-    beam_info_dict = {
-        "position": [],
-        "shape": "",
-        "size_x": 0,
-        "size_y": 0,
-        "label": "",
-    }
-    _beam = beam_info.get_value()
-    beam_info_dict.update(
-        {
-            "position": beam_info.get_beam_position_on_screen(),
-            "size_x": _beam[0],
-            "size_y": _beam[1],
-            "shape": _beam[2].value,
-            "label": _beam[3],
-        }
-    )
-    try:
-        server.emit("beam_changed", {"data": beam_info_dict}, namespace="/hwr")
-    except Exception:
-        logging.getLogger("HWR").exception(
-            "error sending beam_changed signal: %s" % beam_info_dict
-        )
-
-
-def beamline_action_start(name):
-    msg = {"name": name, "state": RUNNING}
-
-    try:
-        server.emit("beamline_action", msg, namespace="/hwr")
-    except Exception:
-        logging.getLogger("HWR").exception(
-            "error sending beamline action message: %s", msg
-        )
-
-
-def beamline_action_done(name, result):
-    try:
-        logging.getLogger("user_level_log").info("Command %s done.", name)
-        msg = {"name": name, "state": READY, "data": result}
-        server.emit("beamline_action", msg, namespace="/hwr")
-    except Exception:
-        logging.getLogger("HWR").exception(
-            "error sending beamline action message: %s", msg
-        )
-
-
-def beamline_action_failed(name):
-    msg = {"name": name, "state": FAILED}
-    try:
-        server.emit("beamline_action", msg, namespace="/hwr")
-    except Exception:
-        logging.getLogger("HWR").exception(
-            "error sending beamline action message: %s", msg
-        )
-    else:
-        logging.getLogger("user_level_log").error("Action %s failed !", name)
-
-
 def new_plot(plot_info):
     try:
         server.emit("new_plot", plot_info, namespace="/hwr")
